%define anolis_release 1

%bcond_with doc

Summary: Qt5 - Connectivity components
Name:    qt5-qtconnectivity
Version: 5.15.9
Release: %{anolis_release}%{?dist}

License: LGPLv2 with exceptions or GPLv3 with exceptions
Url:     http://qt.io

Source0: https://download.qt.io/official_releases/qt/5.15/%{version}/submodules/qtconnectivity-everywhere-opensource-src-%{version}.tar.xz
Patch0: %{name}-gcc11.patch

# filter qml provides
%global __provides_exclude_from ^%{_qt5_archdatadir}/qml/.*\\.so$

BuildRequires: make
BuildRequires: qt5-qtbase-devel >= %{version}
BuildRequires: qt5-qtbase-private-devel >= %{version}
%{?_qt5:Requires: %{_qt5} = %{_qt5_version}}
BuildRequires: qt5-qtdeclarative-devel >= %{version}
BuildRequires: pkgconfig(bluez)

%description
Qt5-QtConnectivity is a high-level Qt module that provides a set of APIs
for developing wireless and wired connectivity applications. It aims to
simplify the development of networked applications and allows developers
to write code that can communicate with various network protocols and
devices.

The module includes classes and functions to handle Bluetooth, NFC, Wi-Fi,
and other wireless technologies. It also provides classes for network
programming, such as QNetworkAccessManager, QNetworkReply, and QNetworkRequest.
These classes allow developers to implement complex network protocols and
manage network communication.

Qt5-QtConnectivity module is a part of the Qt framework, which is a popular
cross-platform application development platform used to create desktop,
mobile, and embedded applications. It offers a consistent, easy-to-use API
across multiple platforms and operating systems, making it a preferred
choice for many developers.

%package devel
Summary: Development files for %{name}
Requires: %{name} = %{version}-%{release}
Requires: qt5-qtbase-devel
%description devel
This package contains the development files for %{name}.

%package examples
Summary: Programming examples for %{name}
Requires: %{name} = %{version}-%{release}
%description examples
This package contains programming examples for %{name}.

%package doc
Summary: Documentation for %{name}
Requires: %{name} = %{version}-%{release}

%description doc
This package contains the documentation for %{name}.

%prep
%autosetup -p1 -n qtconnectivity-everywhere-src-%{version}

%build
%qmake_qt5

%make_build


%install
make install INSTALL_ROOT=%{buildroot}

%if %{with doc}
make install_docs INSTALL_ROOT=%{buildroot}
%endif

# hardlink files to {_bindir}, add -qt5 postfix to not conflict
mkdir %{buildroot}%{_bindir}
pushd %{buildroot}%{_qt5_bindir}
for i in * ; do
  case "${i}" in
    *)
      ln -v  ${i} %{buildroot}%{_bindir}/${i}
      ;;
  esac
done
popd

## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt5_libdir}
for prl_file in libQt5*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd

%files
%license LICENSE.GPL* LICENSE.LGPL*
%{_bindir}/sdpscanner
%{_qt5_bindir}/sdpscanner
%{_qt5_libdir}/libQt5Bluetooth.so.5*
%{_qt5_archdatadir}/qml/QtBluetooth/
%{_qt5_libdir}/libQt5Nfc.so.5*
%{_qt5_archdatadir}/qml/QtNfc/

%files devel
%{_qt5_headerdir}/QtBluetooth/
%{_qt5_libdir}/libQt5Bluetooth.so
%{_qt5_libdir}/libQt5Bluetooth.prl
%dir %{_qt5_libdir}/cmake/Qt5Bluetooth/
%{_qt5_libdir}/cmake/Qt5Bluetooth/Qt5BluetoothConfig*.cmake
%{_qt5_libdir}/pkgconfig/Qt5Bluetooth.pc
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_bluetooth*.pri
%{_qt5_headerdir}/QtNfc/
%{_qt5_libdir}/libQt5Nfc.so
%{_qt5_libdir}/libQt5Nfc.prl
%dir %{_qt5_libdir}/cmake/Qt5Nfc/
%{_qt5_libdir}/cmake/Qt5Nfc/Qt5NfcConfig*.cmake
%{_qt5_libdir}/pkgconfig/Qt5Nfc.pc
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_nfc*.pri

%files examples
%{_qt5_examplesdir}/

%files doc
%doc dist/*

%changelog
* Tue May 23 2023 Funda Wang <fundawang@yeah.net> - 5.15.9-1
- New version 5.15.9

* Thu Apr 13 2023 Kun(llfl) <llfl@linux.alibaba.com> - 5.15.8-2
- optimize spec file

* Thu Jan 19 2023 Funda Wang <fundawang@yeah.net> - 5.15.8-1
- New version 5.15.8

* Wed Dec 7 2022 Funda Wang <fundawang@yeah.ent> - 5.15.7-1
- New version 5.15.7

* Thu Jul 28 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 5.15.5-1
- Init from upstream version 5.15.5
